<?php

	/*
	 *
 	 * UpdateMail - an email update notification extension for pMachine Pro
	 * Author: Albert A. Freeman <acef@drivingmenuts.net>
	 * Documentation: Megan-Jane Daniels-Sueyasu <mjd-s@souzouzone.jp>
	 *
	 * 6/29/2006 - Multiple weblog support!
	 *
	 */


	define('DEFAULT_MAILING_LIST_ID',1);

	class UpdateMail {
	
		var $settings		= array();
		var $name			= 'UpdateMail';
		var $version		= '1.1.0';
		var $description	= 'email notification of blog updates';
		var $settings_exist	= 'y';
		var $docs_url		= 'http://www.drivingmenuts.net';
		
		// ----------------------------------------
		// constructor
		// ----------------------------------------
		function UpdateMail($s='') {
			
			global $LANG;
			
			$this->settings=$s;
			$LANG->fetch_language_file('updatemail');

		} // end constructor UpdateMail
		
		// ----------------------------------------
		// activator
		// ----------------------------------------
		function activate_extension() {
		
			global $DB;
			
			$default_settings=serialize(array(
				'upd_list_id' => DEFAULT_MAILING_LIST_ID
				));
			
			// add our hook for the publish form
			$DB->query(
				$DB->insert_string('exp_extensions',
					array(
						'extension_id'	=> '',
						'class'			=> __CLASS__,
						'method'		=> 'add_verify_send_checkbox',
						'hook'			=> 'publish_form_end',
						'settings'		=> $default_settings,
						'priority'		=> '1',
						'version'		=> $this->version,
						'enabled'		=> 'y'
					)
				)
			); // end $DB->query

			// add our hook for the end of the submit process
			$DB->query(
				$DB->insert_string('exp_extensions',
					array(
						'extension_id'	=> '',
						'class'			=> __CLASS__,
						'method'		=> 'send_update_mail',
						'hook'			=> 'submit_new_entry_end',
						'settings'		=> $default_settings,
						'priority'		=> '1',
						'version'		=> $this->version,
						'enabled'		=> 'y'
					)
				)
			); // end $DB->query
			
		} // end activate_extension
		
		// ----------------------------------------
		// updater
		// ----------------------------------------
		function update_extension($current='') {

			global $DB;
			
			if ($current == '' OR $current == $this->version)
				return false;
			
			$DB->query("UPDATE exp_extensions SET version = '".
				$DB->escape_str($this->version).
				"' WHERE class = '".__CLASS__."'");
		} // end update_extension
		
		// ----------------------------------------
		// disabler
		// ----------------------------------------
		function disable_extension(){

			global $DB;
		
			$DB->query("DELETE FROM exp_extensions WHERE class = '".__CLASS__."'");
		} // end disable_extension

		// ----------------------------------------
		// settings
		// ----------------------------------------
		function settings(){
			
			$defvalue=isset($this->settings['upd_list_id']) ? $this->settings['upd_list_id'] : DEFAULT_MAILING_LIST_ID;
			$settings['upd_list_id']=array('s',$this->fetch_mailing_list_array(),$defvalue);
			
			return $settings;
								
		} // end disable_extension
		
		// ----------------------------------------
		// add_verify_send_checkbox
		// ----------------------------------------
		function add_verify_send_checkbox(){

			global $DSP, $LANG;
			$rval='';
			
			$rval .= $DSP->itemGroup('UpdateMail Extension',
				$DSP->input_checkbox('update_mail_send', 'y', 1).' '.
				$LANG->line('update_mail_send','update_mail_send').
				$DSP->br(2).
				$LANG->line('update_mail_addlmsg','update_mail_addlmsg').
				$DSP->br().
				$DSP->input_textarea('update_mail_addlmsg','',2,'textarea','50%')
				);

			return $rval;
								
		} // end add_verify_send_checkbox

		// ----------------------------------------
		// fetch_mailing_list_array
		// ----------------------------------------
		function fetch_mailing_list_array(){

			global $DB, $PREFS;
			$rval=array();
			
			$res=$DB->query("SELECT list_id, CONCAT(list_name,' (',list_title,')') as list_name FROM ".$PREFS->ini('db_prefix')."_mailing_lists;");
			foreach($res->result as $row)
				$rval[$row['list_id']]=$row['list_name'];
			
			return $rval;
								
		} // end disable_extension
		
		// ----------------------------------------
		// send_update_mail
		// ----------------------------------------
		function send_update_mail() {
		
			global $DSP, $SESS, $PREFS, $FNS, $DB, $LANG;

			$argl=func_get_args();

			// echo "<pre>"; print_r(get_defined_vars()); echo "</pre>"; die('Sayonara, suckers!');

			// permissions check - 
			if ($SESS->userdata('can_email_mailinglist') != 'y') {     
				return $DSP->no_access_message($LANG->line('not_allowed_to_email_mailinglist'));
			}        
			
			// check to see if we're gonna send or not
			if ($_POST['update_mail_send']=='y') {
				// if this is a published post, then go ahead and send it.
				if ($argl[1]["status"]=="open") {
				
					// get the action id
					$action_id  = $FNS->fetch_action_id('Mailinglist', 'unsubscribe');			
		
					// create the email class
					if ( ! class_exists('EEmail')) {
						require PATH_CORE.'core.email'.EXT;
					}
					$EML = new EEmail;
					
					// create the communicate class
					if ( ! class_exists('Communicate')) {
						require PATH_CP.'cp.communicate'.EXT;
					}
					$COM = new Communicate;
	
					// get the mailing list template
					$email_results=$DB->query("SELECT list_template FROM ".$PREFS->ini('db_prefix')."_mailing_lists WHERE list_id=".$this->settings['upd_list_id'].";");
					$email_template=$email_results->row['list_template'];
					
					// get the url
					$blogurl_results=$DB->query("SELECT blog_name,blog_title FROM ".$PREFS->ini('db_prefix')."_weblogs WHERE weblog_id=".$argl[1]["weblog_id"].";");
					$blog_name=$blogurl_results->row["blog_name"];					
					$blog_title=$blogurl_results->row["blog_title"];					
					$update_message=$LANG->line('update_mail_blurb').
						$FNS->create_url($blog_name."/".$argl[1]["url_title"]).
						".".
						($_POST['update_mail_addlmsg'] ? ' '.$_POST['update_mail_addlmsg'] : '');		
					$message_text=str_replace("{message_text}",$update_message,$email_template);
					
					// get the subscribers
					$subscriber_list=$DB->query("SELECT email,authcode FROM ".$PREFS->ini('db_prefix')."_mailing_list WHERE list_id=".$this->settings['upd_list_id'].";");
					
					// loop thru the subscribers
					foreach($subscriber_list->result as $row) {
					// create the email
						$EML->from($PREFS->ini('webmaster_email'));
						$EML->to($row['email']);
						$EML->subject($LANG->line('update_mail_subject').$blog_title.': '.$argl[1]['title']);
						$EML->message(
								$COM->parse_template($email_template,$update_message,$action_id,$row['authcode'])
							);
						$EML->send();
					}
				} // end if status open
			} // end if send update mail is y
		} // end function send_update_mail
	} // end updateMail

?>